close.RethinkDB_cursor: Close cursor

View source: R/cursor.R

close.RethinkDB_cursorR Documentation

Close cursor

Description

Closes a given cursor and stops its associated query. Should be called on the current cursor before a new sync query is invoked on the same connection.

Usage

## S3 method for class 'RethinkDB_cursor'
close(con, ...)

Arguments

con

Cursor to close.

...

Ignored.


rethinker documentation built on April 23, 2026, 5:07 p.m.