isOpened: Check if connection is opened

View source: R/wire.R

isOpenedR Documentation

Check if connection is opened

Description

Check whether a given connection is opened. Closed connections cannot be used, and will throw errors on such an attempt; their associated callbacks and/or sync cursor are dead and won't fire/produce any more data.

Usage

isOpened(x)

Arguments

x

Connection to to check.

Value

TRUE if connection is opened and can be used for queries, FALSE otherwise.

Author(s)

Miron B. Kursa


rethinker documentation built on April 23, 2026, 5:07 p.m.