| close.RethinkDB_cursor | R Documentation |
Closes a given cursor and stops its associated query. Should be called on the current cursor before a new sync query is invoked on the same connection.
## S3 method for class 'RethinkDB_cursor'
close(con, ...)
con |
Cursor to close. |
... |
Ignored. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.